@@ -30,9 +30,9 @@ typedef struct _mongoc_stream_file_t mongoc_stream_file_t;
 
 
 MONGOC_EXPORT (mongoc_stream_t *)
-mongoc_stream_file_new (int fd);
+mongoc_stream_file_new (int fd) BSON_GNUC_WARN_UNUSED_RESULT;
 MONGOC_EXPORT (mongoc_stream_t *)
-mongoc_stream_file_new_for_path (const char *path, int flags, int mode);
+mongoc_stream_file_new_for_path (const char *path, int flags, int mode) BSON_GNUC_WARN_UNUSED_RESULT;
 MONGOC_EXPORT (int)
 mongoc_stream_file_get_fd (mongoc_stream_file_t *stream);
 
